colour.models.dataset.adobe_rgb_1998 Module — Colour 0.3.0 documentation

# colour.models.dataset.adobe_rgb_1998 Module

## Adobe RGB 1998 Colourspace

Defines the Adobe RGB 1998 colourspace:

- `ADOBE_RGB_1998_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.adobe.com/digitalimag/pdfs/AdobeRGB1998.pdf (Last accessed 24 February 2014)

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_PRIMARIES` = array([[ 0.64, 0.33], [ 0.21, 0.71], [ 0.15, 0.06]])

  Adobe RGB 1998 colourspace primaries.

  ADOBE_RGB_1998_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_WHITEPOINT` = (0.31271, 0.32902)

  Adobe RGB 1998 colourspace whitepoint.

  ADOBE_RGB_1998_WHITEPOINT : tuple

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_TO_XYZ_MATRIX` = array([[ 0.57666809, 0.18556195, 0.1881985 ], [ 0.29734449, 0.62737611, 0.0752794 ], [ 0.02703132, 0.07069027, 0.99117879]])

  Adobe RGB 1998 colourspace to CIE XYZ colourspace matrix.

  ADOBE_RGB_1998_TO_XYZ_MATRIX : array_like, (3, 3)

  References

  [2] | http://www.adobe.com/digitalimag/pdfs/AdobeRGB1998.pdf: 4.3.5.3 Converting RGB to normalised XYZ values

`colour.models.dataset.adobe_rgb_1998.` `XYZ_TO_ADOBE_RGB_1998_MATRIX` = array([[ 2.04159129, -0.56500792, -0.34473191], [-0.96922428, 1.87593 , 0.04155423], [ 0.01344643, -0.11838136, 1.01533759]])

  CIE XYZ colourspace to Adobe RGB 1998 colourspace matrix.

  XYZ_TO_ADOBE_RGB_1998_MATRIX : array_like, (3, 3)

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Adobe RGB 1998 colourspace.

  ADOBE_RGB_1998_TRANSFER_FUNCTION : object

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Adobe RGB 1998 colourspace to linear.

  ADOBE_RGB_1998_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.adobe_rgb_1998.` `ADOBE_RGB_1998_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e126d0>

  Adobe RGB 1998 colourspace.

  ADOBE_RGB_1998_COLOURSPACE : RGB_Colourspace